/*
** Generated by X-Designer
*/
#ifndef _resize_h
#define _resize_h

#define XD_MOTIF



extern Widget shell;
extern Widget topform;
extern Widget subform;
extern Widget menubar;
extern Widget help_b;
extern Widget drawable;

extern void create_shell (Display *, char *, int, char **);



#endif
